@@ -1,17 +1,14 @@
 import pymongo
-
-from . import _connector
+import typing
 
 
-class Connector(
-    _connector.Connector,
-):
+class Connector:
     name = 'mongo'
 
     def __init__(
         self,
-        mongodb_uri,
-    ):
+        mongodb_uri: str,
+    ) -> None:
         self.mongodb_uri = mongodb_uri
         self.connection = pymongo.MongoClient(
             host=mongodb_uri,
@@ -42,9 +39,9 @@ class Connector(
 
     def key_set(
         self,
-        key,
-        value,
-    ):
+        key: str,
+        value: bytes,
+    ) -> bool:
         update_one_result = self.connection.sergeant.keys.update_one(
             filter={
                 'key': key,
@@ -64,8 +61,8 @@ class Connector(
 
     def key_get(
         self,
-        key,
-    ):
+        key: str,
+    ) -> typing.Optional[bytes]:
         document = self.connection.sergeant.keys.find_one(
             filter={
                 'key': key,
@@ -78,8 +75,8 @@ class Connector(
 
     def key_delete(
         self,
-        key,
-    ):
+        key: str,
+    ) -> bool:
         delete_one_result = self.connection.sergeant.keys.delete_one(
             filter={
                 'key': key,
@@ -90,8 +87,8 @@ class Connector(
 
     def queue_pop(
         self,
-        queue_name,
-    ):
+        queue_name: str,
+    ) -> typing.Optional[bytes]:
         document = self.connection.sergeant.task_queue.find_one_and_delete(
             filter={
                 'queue_name': queue_name,
@@ -113,9 +110,9 @@ class Connector(
 
     def queue_pop_bulk(
         self,
-        queue_name,
-        number_of_items,
-    ):
+        queue_name: str,
+        number_of_items: int,
+    ) -> typing.List[bytes]:
         documents = []
         for i in range(number_of_items):
             document = self.connection.sergeant.task_queue.find_one_and_delete(
@@ -141,10 +138,10 @@ class Connector(
 
     def queue_push(
         self,
-        queue_name,
-        item,
-        priority='NORMAL',
-    ):
+        queue_name: str,
+        item: bytes,
+        priority: str = 'NORMAL',
+    ) -> bool:
         if priority == 'HIGH':
             priority_value = 0
         elif priority == 'NORMAL':
@@ -162,10 +159,10 @@ class Connector(
 
     def queue_push_bulk(
         self,
-        queue_name,
-        items,
-        priority='NORMAL',
-    ):
+        queue_name: str,
+        items: typing.Iterable[bytes],
+        priority: str = 'NORMAL',
+    ) -> bool:
         if priority == 'HIGH':
             priority_value = 0
         elif priority == 'NORMAL':
@@ -186,8 +183,8 @@ class Connector(
 
     def queue_length(
         self,
-        queue_name,
-    ):
+        queue_name: str,
+    ) -> int:
         queue_length = self.connection.sergeant.task_queue.count_documents(
             filter={
                 'queue_name': queue_name,
@@ -198,12 +195,12 @@ class Connector(
 
     def queue_delete(
         self,
-        queue_name,
-    ):
+        queue_name: str,
+    ) -> bool:
         result = self.connection.sergeant.task_queue.delete_many(
             filter={
                 'queue_name': queue_name,
             },
         )
 
-        return result.deleted_count
+        return result.deleted_count > 0
