@@ -1,9 +1,11 @@
 import time
+import datetime
+import logging
+import typing
 
 from . import config
 from . import connector
 from . import encoder
-from . import logger
 from . import task_queue
 from . import executor
 
@@ -19,29 +21,42 @@ class Worker:
 
     def init_worker(
         self,
-    ):
+    ) -> None:
         self.init_task_queue()
         self.init_logger()
         self.init_executor()
 
     def init_logger(
         self,
-    ):
-        self.logger = logger.logger.Logger(
-            logger_name=self.config.name,
-            log_level=self.config.logging.level,
-            log_to_stdout=self.config.logging.log_to_stdout,
+    ) -> None:
+        self.logger = logging.getLogger(
+            name=self.config.name,
         )
+        self.logger.propagate = False
+        self.logger.setLevel(
+            level=self.config.logging.level,
+        )
+
+        if self.config.logging.log_to_stdout:
+            stream_handler = logging.StreamHandler()
+            stream_handler.setFormatter(
+                fmt=logging.Formatter(
+                    fmt='%(asctime)s %(name)-12s %(process)d %(levelname)-8s %(message)s',
+                    datefmt='%Y-%m-%d %H:%M:%S',
+                ),
+            )
+            self.logger.addHandler(
+                hdlr=stream_handler,
+            )
+
         for handler in self.config.logging.handlers:
-            if handler.type == 'logstash':
-                self.logger.add_logstash_handler(
-                    host=handler.params['host'],
-                    port=handler.params['port'],
-                )
+            self.logger.addHandler(
+                hdlr=handler,
+            )
 
     def init_task_queue(
         self,
-    ):
+    ) -> None:
         encoder_obj = encoder.encoder.Encoder(
             compressor_name=self.config.encoder.compressor,
             serializer_name=self.config.encoder.serializer,
@@ -55,7 +70,7 @@ class Worker:
 
     def init_executor(
         self,
-    ):
+    ) -> None:
         if self.config.executor.type == 'serial':
             self.executor_obj = executor.serial.SerialExecutor(
                 worker=self,
@@ -68,8 +83,8 @@ class Worker:
 
     def purge_tasks(
         self,
-        task_name=None,
-    ):
+        task_name: typing.Optional[str] = None,
+    ) -> bool:
         try:
             return self.task_queue.purge_tasks(
                 task_name=task_name if task_name else self.config.name,
@@ -83,8 +98,8 @@ class Worker:
 
     def number_of_enqueued_tasks(
         self,
-        task_name=None,
-    ):
+        task_name: typing.Optional[str] = None,
+    ) -> typing.Optional[int]:
         try:
             return self.task_queue.number_of_enqueued_tasks(
                 task_name=task_name if task_name else self.config.name,
@@ -94,12 +109,14 @@ class Worker:
                 msg=f'could not get the queue length: {exception}',
             )
 
+            return None
+
     def apply_async_one(
         self,
-        kwargs,
-        task_name=None,
-        priority='NORMAL',
-    ):
+        kwargs: typing.Dict[str, typing.Any],
+        task_name: typing.Optional[str] = None,
+        priority: str = 'NORMAL',
+    ) -> bool:
         try:
             task = self.task_queue.craft_task(
                 task_name=task_name if task_name else self.config.name,
@@ -111,20 +128,20 @@ class Worker:
                 priority=priority,
             )
 
-            return task
+            return True
         except Exception as exception:
             self.logger.error(
                 msg=f'could not push task: {exception}',
             )
 
-            return None
+            return False
 
     def apply_async_many(
         self,
-        kwargs_list,
-        task_name=None,
-        priority='NORMAL',
-    ):
+        kwargs_list: typing.Iterable[typing.Dict[str, typing.Any]],
+        task_name: typing.Optional[str] = None,
+        priority: str = 'NORMAL',
+    ) -> bool:
         try:
             if task_name is None:
                 task_name = self.config.name
@@ -151,9 +168,9 @@ class Worker:
 
     def get_next_tasks(
         self,
-        number_of_tasks,
-        task_name=None,
-    ):
+        number_of_tasks: int,
+        task_name: typing.Optional[str] = None,
+    ) -> typing.List[typing.Dict[str, typing.Any]]:
         try:
             return self.task_queue.get_tasks(
                 task_name=task_name if task_name else self.config.name,
@@ -168,7 +185,7 @@ class Worker:
 
     def iterate_tasks(
         self,
-    ):
+    ) -> typing.Iterable[typing.Dict[str, typing.Any]]:
         run_forever = self.config.max_tasks_per_run == 0
         if run_forever:
             yield from self.iterate_tasks_forever()
@@ -177,7 +194,7 @@ class Worker:
 
     def iterate_tasks_forever(
         self,
-    ):
+    ) -> typing.Iterable[typing.Dict[str, typing.Any]]:
         while True:
             tasks = self.get_next_tasks(
                 number_of_tasks=self.config.tasks_per_transaction,
@@ -192,7 +209,7 @@ class Worker:
 
     def iterate_tasks_until_max_tasks(
         self,
-    ):
+    ) -> typing.Iterable[typing.Dict[str, typing.Any]]:
         tasks_left = self.config.max_tasks_per_run
         while tasks_left > 0:
             tasks = self.get_next_tasks(
@@ -214,7 +231,14 @@ class Worker:
 
     def work_loop(
         self,
-    ):
+    ) -> typing.Dict[str, typing.Any]:
+        summary = {
+            'start_time': datetime.datetime.utcnow(),
+            'executor_exception': None,
+            'initialize_exception': None,
+            'finalize_exception': None,
+        }
+
         try:
             self.initialize()
         except Exception as exception:
@@ -222,6 +246,11 @@ class Worker:
                 msg=f'initialize has failed: {exception}',
             )
 
+            summary['end_time'] = datetime.datetime.utcnow()
+            summary['initialize_exception'] = exception
+
+            return summary
+
         try:
             self.executor_obj.execute_tasks(
                 tasks=self.iterate_tasks(),
@@ -231,7 +260,7 @@ class Worker:
                 msg=f'execute_tasks has failed: {exception}',
             )
 
-            raise exception
+            summary['executor_exception'] = exception
         finally:
             try:
                 self.finalize()
@@ -239,12 +268,17 @@ class Worker:
                 self.logger.error(
                     msg=f'finalize has failed: {exception}',
                 )
+                summary['finalize_exception'] = exception
+
+            summary['end_time'] = datetime.datetime.utcnow()
+
+            return summary
 
     def retry(
         self,
-        task,
-        priority='NORMAL',
-    ):
+        task: typing.Dict[str, typing.Any],
+        priority: str = 'NORMAL',
+    ) -> None:
         if self.config.max_retries > 0 and self.config.max_retries <= task['run_count']:
             raise WorkerMaxRetries()
         else:
@@ -257,9 +291,9 @@ class Worker:
 
     def requeue(
         self,
-        task,
-        priority='NORMAL',
-    ):
+        task: typing.Dict[str, typing.Any],
+        priority: str = 'NORMAL',
+    ) -> None:
         self.task_queue.requeue(
             task=task,
             priority=priority,
@@ -269,9 +303,9 @@ class Worker:
 
     def _on_success(
         self,
-        task,
-        returned_value,
-    ):
+        task: typing.Dict[str, typing.Any],
+        returned_value: typing.Any,
+    ) -> None:
         try:
             if self.config.logging.events.on_success:
                 self.logger.info(
@@ -295,9 +329,9 @@ class Worker:
 
     def _on_failure(
         self,
-        task,
-        exception,
-    ):
+        task: typing.Dict[str, typing.Any],
+        exception: Exception,
+    ) -> None:
         try:
             if self.config.logging.events.on_failure:
                 self.logger.error(
@@ -321,8 +355,8 @@ class Worker:
 
     def _on_timeout(
         self,
-        task,
-    ):
+        task: typing.Dict[str, typing.Any],
+    ) -> None:
         try:
             if self.config.logging.events.on_timeout:
                 self.logger.error(
@@ -345,8 +379,8 @@ class Worker:
 
     def _on_retry(
         self,
-        task,
-    ):
+        task: typing.Dict[str, typing.Any],
+    ) -> None:
         try:
             if self.config.logging.events.on_retry:
                 self.logger.info(
@@ -369,8 +403,8 @@ class Worker:
 
     def _on_max_retries(
         self,
-        task,
-    ):
+        task: typing.Dict[str, typing.Any],
+    ) -> None:
         try:
             if self.config.logging.events.on_max_retries:
                 self.logger.error(
@@ -393,8 +427,8 @@ class Worker:
 
     def _on_requeue(
         self,
-        task,
-    ):
+        task: typing.Dict[str, typing.Any],
+    ) -> None:
         try:
             if self.config.logging.events.on_requeue:
                 self.logger.info(
@@ -417,70 +451,70 @@ class Worker:
 
     def initialize(
         self,
-    ):
+    ) -> None:
         pass
 
     def finalize(
         self,
-    ):
+    ) -> None:
         pass
 
     def pre_work(
         self,
-        task,
-    ):
+        task: typing.Dict[str, typing.Any],
+    ) -> None:
         pass
 
     def post_work(
         self,
-        task,
-        success,
-        exception,
-    ):
+        task: typing.Dict[str, typing.Any],
+        success: bool,
+        exception: typing.Optional[Exception],
+    ) -> None:
         pass
 
     def work(
         self,
-        task,
-    ):
+        task: typing.Dict[str, typing.Any],
+    ) -> typing.Any:
         pass
 
     def on_success(
         self,
-        task,
-        returned_value,
-    ):
+        task: typing.Dict[str, typing.Any],
+        returned_value: typing.Any,
+    ) -> None:
         pass
 
     def on_failure(
         self,
-        task,
-        exception,
-    ):
+        task: typing.Dict[str, typing.Any],
+        exception: Exception,
+    ) -> None:
         pass
 
     def on_timeout(
         self,
-        task,
-    ):
+        task: typing.Dict[str, typing.Any],
+    ) -> None:
         pass
 
     def on_retry(
         self,
-        task,
-    ):
+        task: typing.Dict[str, typing.Any],
+    ) -> None:
         pass
 
     def on_requeue(
         self,
-        task,
-    ):
+        task: typing.Dict[str, typing.Any],
+    ) -> None:
         pass
 
     def on_max_retries(
         self,
-        task,
-    ):
+        task: typing.Dict[str, typing.Any],
+    ) -> None:
         pass
 
 
